@@ -5,7 +5,7 @@
  * software
  */
 /*
- * $Id: huffd.c,v 1.7 2005/05/15 22:10:20 enlf Exp $
+ * $Id: huffd.c,v 1.8 2013/06/16 21:47:42 enlf Exp $
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -504,14 +504,14 @@ void DecodeImage (DecompressInfo *dcPtr, unsigned short **image, int depth)
     int predictor;
     int numCOL, numROW, compsInScan;
     MCU *prevRowBuf, *curRowBuf;
-    int imagewidth, Pt, psv;
+    int imagewidth, /*Pt,*/ psv;
     unsigned short *image16tmp;
     unsigned char *image8tmp, *image24tmp;
              
     numCOL      = imagewidth=dcPtr->imageWidth;
     numROW      = dcPtr->imageHeight;
     compsInScan = dcPtr->compsInScan;
-    Pt          = dcPtr->Pt;
+    /*Pt          = dcPtr->Pt;*/
     psv         = dcPtr->Ss;
     prevRowBuf  = mcuROW2;
     curRowBuf   = mcuROW1;
