@@ -5,7 +5,7 @@
  * are stolen from the IJG code
  */
 /*
- * $Id: jpegutil.c,v 1.4 2004/08/18 21:38:43 enlf Exp $
+ * $Id: jpegutil.c,v 1.6 2006/12/07 23:49:01 enlf Exp $
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -16,13 +16,16 @@
 
 /*
  * To fix memory leaks, memory is allocated once for the mcu buffers.
- * Enough memory is reserved to accomodate up to 1024-wide images
+ * Enough memory is reserved to accomodate up to MDC_LJPG_LIMIT-wide images
  * with up to 4 components.
  */
-static char mcuROW1Memory[1024 * sizeof(MCU)];
-static char mcuROW2Memory[1024 * sizeof(MCU)];
-static char buf1Memory[1024 * 4 * sizeof(ComponentType)];
-static char buf2Memory[1024 * 4 * sizeof(ComponentType)];
+
+#define MDC_LJPG_LIMIT 4096 /* hardcoded limit of image width */
+
+static char mcuROW1Memory[MDC_LJPG_LIMIT * sizeof(MCU)];
+static char mcuROW2Memory[MDC_LJPG_LIMIT * sizeof(MCU)];
+static char buf1Memory[MDC_LJPG_LIMIT * 4 * sizeof(ComponentType)];
+static char buf2Memory[MDC_LJPG_LIMIT * 4 * sizeof(ComponentType)];
 
 
 unsigned int bitMask[] = {  0xffffffff, 0x7fffffff, 0x3fffffff, 0x1fffffff,
