@@ -41,11 +41,11 @@
  *                MdcHashSDBM()           - Get hash using sdbm method     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-algori.c,v 1.86 2010/08/28 23:44:23 enlf Exp $ 
+/* $Id: m-algori.c,v 1.90 2013/06/23 21:51:19 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -1578,10 +1578,9 @@ Uint8 *MdcMakeBIT32_S(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
   Int32 *buf = (Int32 *)cbuf;
   Uint32 i, n = id->width * id->height;
   double pixval, min, max, idmin, idmax, scale=1.0;
-  double SMAX, UMAX, negmin, posmax;
+  double SMAX, negmin, posmax;
   float newval;
 
-  UMAX = (double)(1 <<  BITS);     /* 4294967296 */
   SMAX = (double)(1 << (BITS-1));  /* 2147483648 */
 
   /* get proper maximum/minimum value */
