@@ -18,11 +18,11 @@
  *                - Mosaic support     - Roland Marcus Rutschmann          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-dicm.c,v 1.185 2010/08/28 23:44:23 enlf Exp $
+/* $Id: m-dicm.c,v 1.189 2013/06/23 21:51:19 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -133,11 +133,9 @@ int MdcCheckDICM(FILEINFO *fi)
    char sig[5];
 
    fseek(fi->ifp,128,SEEK_SET);
-   fread(sig,1,4,fi->ifp);
+   if (fread(sig,1,4,fi->ifp) != 4) return(MDC_BAD_READ);
    fseek(fi->ifp,0,SEEK_SET);
 
-   if (ferror(fi->ifp)) return(MDC_BAD_READ);
-
    sig[4]='\0';
    MdcLowStr(sig);
 
