@@ -60,11 +60,11 @@
  *                MdcAddCompressionExt()  - Add  compression extension     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-fancy.c,v 1.61 2010/08/28 23:44:23 enlf Exp $
+/* $Id: m-fancy.c,v 1.67 2013/06/23 21:51:19 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -155,14 +155,13 @@ void MdcPrintYesNo(int value )
   }
 }
 
-void MdcPrintImageLayout(FILEINFO *fi, Uint32 gen, Uint32 img
-                                     , Uint32 *abs, int repeat)
+void MdcPrintImageLayout(FILEINFO *fi, Uint32 gen, Uint32 img, int repeat)
 {
   IMG_DATA *id;
   Uint32 i;
 
   MdcPrintLine('-',MDC_FULL_LENGTH);
-  MdcPrntScrn("\t\t\tSUMMARY OF IMAGE LAYOUT\n");
+  MdcPrntScrn("\t\t\tSUMMARY OF IMAGE FILE LAYOUT\n");
   MdcPrintLine('-',MDC_FULL_LENGTH);
 
   if ((gen==0) && (img==0))  MdcPrintBoxLine('-',MDC_BOX_SIZE);
@@ -182,7 +181,9 @@ void MdcPrintImageLayout(FILEINFO *fi, Uint32 gen, Uint32 img
      if (fi->endian != MDC_HOST_ENDIAN) MdcPrntScrn("swap !"); 
      else MdcPrntScrn("     !");
      MdcPrntScrn("\t(%ux%ux%u)",id->width,id->height,MdcType2Bytes(id->type));
-     if (abs!=NULL) if (abs[i] > 0) MdcPrntScrn("\tOFFSET: %u",abs[i]);
+     if (id->load_location != 0) {
+       MdcPrntScrn("\tOFFSET: %u",(Uint32)id->load_location);
+     }
      MdcPrntScrn("\n");
 
   }
