@@ -12,13 +12,14 @@
  *                MdcPrintShortInfo()     - Print info to get more help    *
  *                MdcPrintUsage()         - Print usage of medcon options  *
  *                MdcHandleArgs()         - Handle the arguments           *
+ *                MdcApplyReadOptions()   - Apply read options             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-getopt.c,v 1.135 2010/08/28 23:44:23 enlf Exp $
+/* $Id: m-getopt.c,v 1.147 2013/06/23 21:51:19 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -186,7 +187,7 @@ Fallback Read Format: [-fb-none|-fb-anlz|-fb-conc|-fb-ecat|fb-dicom]\n\
 Slices Transform: [-fh -fv] [-rs -cs -cu] [-sqr | -sqr2] [-crop=<X>:<Y>:<W>:<H>]\n\t\t[-pad | -padtl | -padbr]\
 \n  -fh, --flip-horizontal        flip images horizontally (along x-axis)\
 \n  -fv, --flip-vertical          flip images vertically   (along y-axis)\
-\n  -sqr, --make-square           make square images (lagest dimension)\
+\n  -sqr, --make-square           make square images (largest dimension)\
 \n  -sqr2, --make-square-two      make square images (nearest power)");
   MdcPrntScrn("\
 \n  -crop, --crop-images          crop image dimensions\
@@ -328,7 +329,7 @@ void MdcPrintShortInfo(void)
   }
     MdcPrntScrn(" Medical Image Conversion Utility\n");
     MdcPrntScrn("(X)MedCon %s\n",MdcGetLibShortVersion());
-    MdcPrntScrn("Copyright (C) 1997-2010 by Erik Nolf\n\n");
+    MdcPrntScrn("Copyright (C) 1997-2013 by Erik Nolf\n\n");
 
   if (XMDC_GUI == MDC_YES) {
     MdcPrntScrn("Try \'xmedcon --help\' for more information.\n\n");
@@ -361,7 +362,7 @@ void MdcPrintUsage(char *pgrname)
   MdcPrntScrn("[-o <basename>]\n");
   MdcPrntScrn("\n");
   MdcPrntScrn("  -e, --extract            extract images from file\n");
-  MdcPrntScrn("  -i, --interactive        read files after user input\n");
+  MdcPrntScrn("  -i, --interactive        read raw files after user input\n");
   MdcPrntScrn("  -o, --output-name        output name set from command-line\n");
   MdcPrntScrn("  -p, --print-values       print values of specified pixels\n");
   MdcPrntScrn("  -pa, --print-all-values  print all values without asking\n");
@@ -968,7 +969,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
       MdcPrntWarn("Options '-stack'   not available to GUI front-end");
     }
     if ((MDC_GIF_OPTIONS == MDC_YES) || (MDC_ANLZ_OPTIONS == MDC_YES)) {
-      MdcPrntWarn("Options '-optxxx'  not available to GUI front-end");
+      MdcPrntWarn("Options '-opt***'  not available to GUI front-end");
     }
   }
 
@@ -982,12 +983,20 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
     MdcPrntErr(MDC_NO_CODE,"Stacking only supported for true color or gray");
   }
 
+  /* print database info; legacy option, just used within ECAT */
+  if (MDC_INFO_DB == MDC_YES) {
+    if (total[MDC_FILES] > 1)
+      MdcPrntErr(MDC_NO_CODE,"Option '-db' only usefull one file at a time");
+    if (MDC_CONVERT == MDC_YES)
+      MdcPrntErr(MDC_NO_CODE,"Option '-db' useless with '-c' conversion");
+  }
+
   /* echo alias name; single option allowed */
   if (MDC_ECHO_ALIAS == MDC_YES) {
     if (total[MDC_FILES] > 1)
       MdcPrntErr(MDC_NO_CODE,"Option '-ean' only usefull one file at a time");
     if (MDC_CONVERT == MDC_YES)
-      MdcPrntErr(MDC_NO_CODE,"Option '-ean' useless during conversion");
+      MdcPrntErr(MDC_NO_CODE,"Option '-ean' useless with '-c' conversion");
   }
 
   /* useless sorting selections */
@@ -1067,9 +1076,9 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
   }else{
     /* without output file */
     if (MDC_RENAME == MDC_YES)
-      MdcPrntWarn("Option '-r' rename file ignored");
+      MdcPrntErr(MDC_NO_CODE,"Option '-r' requires '-c' conversion specified");
     if (MDC_EXTRACT == MDC_YES)
-      MdcPrntErr(MDC_NO_CODE,"Need conversion specification");
+      MdcPrntErr(MDC_NO_CODE,"Option '-e' requires '-c' conversion specified");
   }
 
   /* study identification */
@@ -1202,3 +1211,40 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
 
 }
 
+char *MdcApplyReadOptions(FILEINFO *fi)
+{
+  char *msg=NULL;
+
+  /* anonymize patient information */
+  if (MDC_PATIENT_ANON) MdcMakePatAnonymous(fi);
+
+  /* ask for patient information */
+  if (MDC_PATIENT_IDENT) MdcGivePatInformation(fi);
+
+  /* edit the FILEINFO structure */
+  if (MDC_EDIT_FI) {
+    if ((msg = MdcEditFI(fi)) != NULL) return(msg);
+  }
+
+  /* print FILEINFO structure */  
+  if (MDC_DEBUG)  MdcPrintFI(fi);
+
+  /* print out pixel requested values */
+  if (MDC_PIXELS) MdcDisplayPixels(fi);
+
+  /* extract some images */
+  if (MDC_EXTRACT) {
+    if ((msg = MdcExtractImages(fi)) != NULL) return(msg);
+  }
+
+  /* reslice images as specified */
+  if (MDC_RESLICE != MDC_NO) {
+    if ((msg = MdcResliceImages(fi, MDC_RESLICE)) != NULL) return(msg);
+  }
+
+  /* rename base filename */
+  if (MDC_RENAME) MdcRenameFile(fi->ifname);
+
+  return(NULL);
+
+}
