@@ -16,11 +16,11 @@
  * Notes        : code fragments from 'example.c' included with PNG lib    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-png.c,v 1.38 2010/08/28 23:44:23 enlf Exp $
+/* $Id: m-png.c,v 1.42 2013/06/23 21:51:19 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -65,7 +65,7 @@ static void MdcPngErr(png_structp png_ptr, png_const_charp error_msg)
 
   if (!png_ptr) return; 
 
-  longjmp(png_ptr->jmpbuf, 1);
+  longjmp(png_jmpbuf(png_ptr), 1);
 }
 
 static void MdcPngWarn(png_structp png_ptr, png_const_charp warning_msg)
@@ -102,6 +102,8 @@ char *MdcReadPNG(FILEINFO *fi)
   int bit_depth, color_type, transform, num_palette;
   Uint8 *imgRGB, *pbuf;
   IMG_DATA *id;
+  int num_text;
+  png_textp text_ptr;
 
   if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_BEGIN,0.,"Reading PNG:");
 
@@ -161,21 +163,22 @@ char *MdcReadPNG(FILEINFO *fi)
   }
 
   /* get comment */
-  if(info_ptr->num_text > 0) {
+  png_get_text(png_ptr,info_ptr,&text_ptr,&num_text);
+  if(num_text > 0) {
     commentsize = 1;
 
-    for(i = 0; i < info_ptr->num_text; i++)
-      commentsize += strlen(info_ptr->text[i].key) + 1 +
-                     info_ptr->text[i].text_length + 2;
+    for(i = 0; i < num_text; i++)
+      commentsize += strlen(text_ptr[i].key) + 1 +
+                     text_ptr[i].text_length + 2;
     
     if ((fi->comment = malloc(commentsize)) == NULL) {
       MdcPngWarn(png_ptr,"PNG  Can't malloc comment string");
     }else{ 
       fi->comment[0] = '\0';
-      for (i = 0; i < info_ptr->num_text; i++) {
-        strcat(fi->comment, info_ptr->text[i].key);
+      for (i = 0; i < num_text; i++) {
+        strcat(fi->comment, text_ptr[i].key);
         strcat(fi->comment, "::");
-        strcat(fi->comment, info_ptr->text[i].text);
+        strcat(fi->comment, text_ptr[i].text);
         strcat(fi->comment, "\n");
       }
     }
