@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-raw.h,v 1.12 2008/01/23 21:28:36 enlf Exp $
+/* $Id: m-raw.h,v 1.21 2013/06/23 21:51:19 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2008 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -41,8 +41,7 @@
 typedef struct MdcRawInputStruct_t {
 
   Uint32 gen_offset, img_offset;
-  Uint32 *abs_offset;
-  Int8 DIFF, REPEAT;
+  Int8 DIFF, REPEAT, REDO;
 
 }MdcRawInputStruct;
 
@@ -51,7 +50,7 @@ typedef struct MdcRawPrevInputStruct_t {
   Uint32 XDIM, YDIM, NRIMGS;
   Uint32 GENHDR, IMGHDR, ABSHDR;
   Int16  PTYPE;
-  Int8   DIFF, HDRREP, PSWAP;
+  Int8   DIFF, HDRREP, PSWAP, REDO;
 
 }MdcRawPrevInputStruct;
 
@@ -62,6 +61,9 @@ extern MdcRawPrevInputStruct mdcrawprevinput;
                             F U N C T I O N S
 ****************************************************************************/
 void MdcInitRawPrevInput(void);
+char *MdcGetRawInput(FILEINFO *fi);
+char *MdcUsePrevRawInput(FILEINFO *fi);
+char *MdcAskRawInput(FILEINFO *fi);
 char *MdcReadRAW(FILEINFO *fi);
 char *MdcWriteRAW(FILEINFO *fi);
 int MdcCheckPredef(const char *fname);
