@@ -13,11 +13,11 @@
  *                MdcStackFiles()          - Main stack routine            *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-stack.c,v 1.40 2010/08/28 23:44:23 enlf Exp $
+/* $Id: m-stack.c,v 1.46 2013/06/23 21:51:19 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -123,7 +123,6 @@ char *MdcStackSlices(void)
        MdcCopyFI(ofi,ifi,MDC_NO,MDC_NO);
 
        /* set some specific parameters */
-       MdcSplitPath(ofi->ipath,ofi->idir,ofi->ifname);
        ofi->dim[0] = 3;
        ofi->dim[1] = ifi->dim[1];
        ofi->dim[2] = ifi->dim[2];
@@ -266,10 +265,20 @@ char *MdcStackSlices(void)
     ofi->image[0].slice_spacing = ofi->image[1].slice_spacing;
   }
 
+  /* apply read options */
+  msg = MdcApplyReadOptions(ofi);
+  if (msg != NULL) {
+    MdcCleanUpFI(ofi);
+    sprintf(mdcbufr,"stack slices : %s",msg); return(mdcbufr);
+  }
+
   /* if requested, reverse slices */
   if (MDC_SORT_REVERSE == MDC_YES) {
     msg = MdcSortReverse(ofi);
-    if (msg != NULL) return(msg); 
+    if (msg != NULL) {
+      MdcCleanUpFI(ofi);
+      sprintf(mdcbufr,"stack slices : %s",msg); return(mdcbufr);
+    }
   }
 
   /* write the file */
@@ -467,6 +476,13 @@ char *MdcStackFrames(void)
     }
   }
 
+  /* apply read options */
+  msg = MdcApplyReadOptions(ofi);
+  if (msg != NULL) {
+    MdcCleanUpFI(ofi);
+    sprintf(mdcbufr,"stack frames : %s",msg); return(mdcbufr);
+  }
+
   /* write the file */
   if (total[MDC_CONVS] > 0) {
     /* go through conversion formats */
