@@ -10,11 +10,11 @@
  * Functions    : main()             -  The hart of the project            *
  *                                                                         * 
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: medcon.c,v 1.27 2010/08/28 23:44:23 enlf Exp $
+/* $Id: medcon.c,v 1.36 2013/06/23 21:51:20 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -64,16 +64,17 @@ int main(int argc, char *argv[])
   if (MdcHandleArgs(&fi,argc,argv,MDC_MAX_FILES) != MDC_OK) 
     MdcPrintUsage(NULL);
 
-  if (MDC_FILE_STACK != MDC_NO) {
-    /* stack files, leave program afterwards */
-    msg = MdcStackFiles(MDC_FILE_STACK);
-    if (msg != NULL) MdcPrntErr(MDC_BAD_CODE,msg);
-    return(MDC_OK);
-  }
-
   /* initialize raw read input */
   if (MDC_INTERACTIVE) MdcInitRawPrevInput();
 
+  /* stack slices or frames */
+  if (MDC_FILE_STACK != MDC_NO) {
+    msg = MdcStackFiles(MDC_FILE_STACK);
+    if (msg != NULL) MdcPrntErr(MDC_BAD_CODE,msg);
+    return(MDC_OK); /* leave program */
+  }
+
+
   /* do the stuff for each input file */
   for (f=0; f<total[MDC_FILES]; f++) {
 
@@ -98,51 +99,19 @@ int main(int argc, char *argv[])
      /* echo alias name on one file at a time; nothing else allowed */
      if (MDC_ECHO_ALIAS) { MdcCleanUpFI(&fi); return(MDC_OK); }
 
-     /* only printing database info */
+     /* just print legady database info */
      if (MDC_INFO_DB) continue;
 
-     /* anonymize patient information */
-     if (MDC_PATIENT_ANON) MdcMakePatAnonymous(&fi);
-
-     /* ask for patient information */
-     if (MDC_PATIENT_IDENT) MdcGivePatInformation(&fi);
-
-     /* edit the FILEINFO structure */
-     if (MDC_EDIT_FI) {
-       if ((msg = MdcEditFI(&fi)) != NULL) {
-         MdcCleanUpFI(&fi);
-         MdcPrntErr(MDC_BAD_CODE,"Failed Info Edit - %s",msg);
-       }
-     }
-
-     /* print FILEINFO structure */  
-     if (MDC_DEBUG)  MdcPrintFI(&fi);
-
-     /* print out pixel requested values */
-     if (MDC_PIXELS) MdcDisplayPixels(&fi);
-
-     /* extract some images */
-     if (MDC_EXTRACT) { 
-       if ((msg = MdcExtractImages(&fi)) != NULL) {
-         MdcCleanUpFI(&fi);
-         MdcPrntErr(error,"Failed Extract - %s",msg);
-       }
-     }
-
-     if (MDC_RESLICE != MDC_NO) {
-       msg=MdcResliceImages(&fi, MDC_RESLICE);
-       if (msg != NULL) {
-         MdcCleanUpFI(&fi);
-         MdcPrntErr(MDC_BAD_CODE,"Failed Reslice - %s",msg);
-       }
+     /* apply some read options */
+     msg = MdcApplyReadOptions(&fi);
+     if (msg != NULL) {
+       MdcCleanUpFI(&fi);
+       MdcPrntErr(MDC_BAD_CODE,msg);
      }
 
      /* when conversions selected */
      if ( total[MDC_CONVS] > 0 ) {
 
-       /* rename base filename */
-       if (MDC_RENAME) MdcRenameFile(fi.ifname);
-
        /* go through all the formats */
        for (c=1; c<MDC_MAX_FRMTS; c++) {
           convert = convs[c];
