@@ -20,11 +20,11 @@
  *                XMdcColGbcCorrectSel();         - GBC selection          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xcolgbc.c,v 1.22 2010/08/28 23:44:23 enlf Exp $
+/* $Id: xcolgbc.c,v 1.26 2013/06/23 21:51:20 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -100,10 +100,10 @@ void XMdcColGbcCorrectUpdate(void)
   w = gdk_pixbuf_get_width(sGbc.im);
   h = gdk_pixbuf_get_height(sGbc.im);
 
-  gdk_pixbuf_unref(sGbc.im);
+  g_object_unref(sGbc.im);
 
   imnew = gdk_pixbuf_scale_simple(imtmp,w,h,sRenderSelection.Interp);
-  gdk_pixbuf_unref(imtmp); sGbc.im = imnew;
+  g_object_unref(imtmp); sGbc.im = imnew;
 
   gdk_pixbuf_render_to_drawable(sGbc.im,area->window,gc,0,0,0,0,w,h,
                                 sRenderSelection.Dither,0,0);
@@ -119,21 +119,21 @@ void XMdcColGbcCorrectMakeIcons(void)
   im = gdk_pixbuf_add_alpha(im0,TRUE,0xff,0x00,0xff);
   gdk_pixbuf_render_pixmap_and_mask(im,&sGbc.brightness_pmap
                                       ,&sGbc.brightness_mask,254);
-  gdk_pixbuf_unref(im); gdk_pixbuf_unref(im0);
+  g_object_unref(im); g_object_unref(im0);
 
   im0=gdk_pixbuf_new_from_data(xmdc_contrast_icon,   GDK_COLORSPACE_RGB, FALSE,
                                8, 12, 12, 3*12, (void(*)())NULL, NULL);
   im = gdk_pixbuf_add_alpha(im0,TRUE,0xff,0x00,0xff);
   gdk_pixbuf_render_pixmap_and_mask(im,&sGbc.contrast_pmap
                                       ,&sGbc.contrast_mask,254);
-  gdk_pixbuf_unref(im); gdk_pixbuf_unref(im0);
+  g_object_unref(im); g_object_unref(im0);
 
   im0=gdk_pixbuf_new_from_data(xmdc_gamma_icon,      GDK_COLORSPACE_RGB, FALSE,
                                8, 12, 12, 3*12, (void(*)())NULL, NULL);
   im = gdk_pixbuf_add_alpha(im0,TRUE,0xff,0x00,0xff);
   gdk_pixbuf_render_pixmap_and_mask(im,&sGbc.gamma_pmap
                                       ,&sGbc.gamma_mask,254);
-  gdk_pixbuf_unref(im); gdk_pixbuf_unref(im0);
+  g_object_unref(im); g_object_unref(im0);
 
 }
 
@@ -363,7 +363,7 @@ void XMdcColGbcCorrectSel(GtkWidget *widget, Uint32 nr)
 
     gtk_window_set_policy(GTK_WINDOW(wgbc), TRUE, TRUE, TRUE);
 
-    gdk_pixbuf_unref(sGbc.im);
+    g_object_unref(sGbc.im);
 
     sGbc.im = im;
 
