@@ -23,11 +23,11 @@
  *                                                                         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xcolmap.c,v 1.32 2010/08/28 23:44:23 enlf Exp $
+/* $Id: xcolmap.c,v 1.37 2013/06/23 21:51:20 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -80,7 +80,7 @@ Uint8 XMDC_CMAP_PLACE = MDC_RIGHT;
 
 void XMdcRemovePreviousColorMap(void)
 {
-  gdk_pixbuf_unref(my.imcmap); 
+  g_object_unref(my.imcmap); 
 }
 
 void XMdcApplyNewColorMap(int map)
@@ -323,11 +323,11 @@ gboolean XMdcColorMapSel(void)
 gboolean XMdcColorMapCallbackExpose(GtkWidget *widget,GdkEventExpose *event,gpointer data)
 {
   GdkGC *gc = widget->style->white_gc;
-  gint w, h;
+  gint /*w,*/ h;
 
   gdk_window_set_back_pixmap(widget->window, NULL, FALSE);
 
-  w = my.cmap_w; 
+  /*w = my.cmap_w;*/
   h = my.cmap_h;
 
   gdk_pixbuf_render_to_drawable(my.imcmap,widget->window,gc, 0,0,0,0,25,h,
