@@ -20,11 +20,11 @@
  *                XMdcGetHeaderInfo()             - Ask Hdr Info           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xreader.c,v 1.28 2010/08/28 23:44:23 enlf Exp $
+/* $Id: xreader.c,v 1.34 2013/06/23 21:51:20 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -199,16 +199,6 @@ void XMdcRawReadPredef(GtkWidget *fs)
     return;
   }
 
-  /* actually unused here, only identical images suppported */
-  input->abs_offset=(Uint32 *)malloc(my.fi->number*sizeof(Uint32));
-  if (input->abs_offset == NULL) {
-    MdcCleanUpFI(my.fi);
-    XMdcDisplayErr("Couldn't malloc abs_offset[]");
-    return;
-  }else{
-    memset(input->abs_offset,0,my.fi->number*sizeof(Uint32));
-  }
-
   for (i=0; i<my.fi->number; i++) {
      id = &my.fi->image[i];
      id->width = prev->XDIM;
@@ -236,7 +226,6 @@ void XMdcRawReadPredef(GtkWidget *fs)
 
 void XMdcRawReadCancel(guint otype)
 {
-  MdcFree(input->abs_offset);
   MdcCleanUpFI(my.fi);
   if (otype == XMDC_RAW)
     gtk_widget_destroy(sRawReadSelection.HdrInfoWindow);
@@ -285,7 +274,7 @@ void XMdcGetImageInfoCallbackApply(void)
 {
   IMG_DATA *id=NULL;
   const char *entry;
-  Uint32 i, width, height, offset, imgnr;
+  Uint32 i, width, height, imgnr, offset;
   Int16 type;
 
   imgnr = raw->ImgCounter - 1;
@@ -314,8 +303,8 @@ void XMdcGetImageInfoCallbackApply(void)
   }
 
   if (input->DIFF) {
-    input->abs_offset[imgnr] = offset;
     id = &my.fi->image[imgnr];
+    id->load_location = (size_t)offset;
     id->width = width;
     id->height= height;
     id->type  = type; 
@@ -324,8 +313,8 @@ void XMdcGetImageInfoCallbackApply(void)
   }else{
 
     for (i=0; i<my.fi->number; i++) {
-       input->abs_offset[i] = offset;
        id = &my.fi->image[i];
+       id->load_location = (size_t)offset;
        id->width = width;
        id->height= height;
        id->type  = type;
@@ -677,15 +666,6 @@ void XMdcGetHeaderInfoCallbackApply(void)
     raw->ImgCounter = 1;
   }
 
-  input->abs_offset=(Uint32 *)malloc(my.fi->number*sizeof(Uint32));
-  if (input->abs_offset == NULL) {
-    XMdcRawReadCancel(XMDC_RAW);
-    XMdcDisplayErr("Couldn't malloc abs_offset[]");
-    return;
-  }else{
-    memset(input->abs_offset,0,my.fi->number*sizeof(Uint32));
-  }
-
   XMdcGetImageInfo();
 
 }
