@@ -13,11 +13,11 @@
  *                XMdcColorMapReset()  - Reset to a new colormap           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xreset.c,v 1.17 2010/08/28 23:44:23 enlf Exp $
+/* $Id: xreset.c,v 1.21 2013/06/23 21:51:20 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -66,9 +66,9 @@ void XMdcViewerReset(void)
     MdcDebugPrint("Removing viewer box & images ...");
     gtk_widget_destroy(my.viewbox); 
     gtk_widget_unrealize(my.viewwindow);
-    gdk_pixbuf_unref(my.imcmap);
+    g_object_unref(my.imcmap);
 
-    for (i=0; i<my.real_images_on_page; i++) gdk_pixbuf_unref(my.im[i]);
+    for (i=0; i<my.real_images_on_page; i++) g_object_unref(my.im[i]);
 
     MdcFree(my.im);
     MdcFree(my.pagenumber);
