@@ -13,11 +13,11 @@
  *                XMdcResizeNeeded()           - Resize when image>screen? *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xresize.c,v 1.23 2010/08/28 23:44:23 enlf Exp $
+/* $Id: xresize.c,v 1.27 2013/06/23 21:51:20 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -280,9 +280,9 @@ void XMdcResizeNeeded(void)
   if (XMdcScaleW(my.fi->mwidth)  >= (gdk_screen_width()  - XMDC_FREE_BORDER) || 
       XMdcScaleH(my.fi->mheight) >= (gdk_screen_height() - XMDC_FREE_BORDER)) {
 
-    XMdcAskYesNo( GTK_SIGNAL_FUNC(XMdcResizeSel),
-                  GTK_SIGNAL_FUNC(XMdcViewerShow),
-                  "Images too big for screen. Choose to resize?");
+    XMdcAskYesNo( GTK_SIGNAL_FUNC(XMdcViewerShow),
+                  GTK_SIGNAL_FUNC(XMdcResizeSel),
+                  "Images too big for screen. Show images anyway?");
 
     XMdcViewerHide();
 
