@@ -13,11 +13,11 @@
  *                XMdcImagesZoom()                - Display zoomed image   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xzoom.c,v 1.23 2010/08/28 23:44:23 enlf Exp $
+/* $Id: xzoom.c,v 1.27 2013/06/23 21:51:20 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2010 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -108,8 +108,8 @@ static void XMdcRemoveZoomStruct(GtkWidget *window, gpointer data)
   ZoomStruct *zoom = (ZoomStruct *)data;
 
   if (zoom != NULL) {
-    if (zoom->im  != NULL) gdk_pixbuf_unref(zoom->im); 
-    if (zoom->cur != NULL) gdk_pixbuf_unref(zoom->cur);
+    if (zoom->im  != NULL) g_object_unref(zoom->im); 
+    if (zoom->cur != NULL) g_object_unref(zoom->cur);
     MdcFree(zoom); 
   }
 
@@ -166,7 +166,7 @@ void XMdcImagesZoomIn(GtkWidget *window)
   gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
 
   new = gdk_pixbuf_scale_simple(zoom->im,w,h,sRenderSelection.Interp); 
-  gdk_pixbuf_unref(zoom->cur); zoom->cur = new;
+  g_object_unref(zoom->cur); zoom->cur = new;
 
   gtk_drawing_area_size(GTK_DRAWING_AREA(zoom->darea),w,h);
 
@@ -212,7 +212,7 @@ void XMdcImagesZoomOut(GtkWidget *window)
   gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
 
   new = gdk_pixbuf_scale_simple(zoom->im,w,h,sRenderSelection.Interp);
-  gdk_pixbuf_unref(zoom->cur); zoom->cur = new;
+  g_object_unref(zoom->cur); zoom->cur = new;
 
   gtk_drawing_area_size(GTK_DRAWING_AREA(zoom->darea),w,h);
 
